<?php

/**
 *
 */
namespace Drupal\moderation_team\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure moderation_team settings for this site.
 */
class ModerationTeamSettingsForm extends ConfigFormBase {

  /** @var string Config settings */
  const SETTINGS = 'moderation_team.settings';

  /** 
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mt_admin_settings';
  }

  /** 
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /** 
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $options = [];
    $config = $this->config(static::SETTINGS);
    $node_types = \Drupal\node\Entity\NodeType::loadMultiple();

    foreach ($node_types as $node_type) {
      $options[$node_type->id()] = $node_type->label();
    }

    $form['mt_content_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Content Type'),
      '#options' => $options,
      '#default_value' => $config->get('mt_content_type'),
    ];

    $form['mt_max_queue'] = [
      '#type' => 'number',
      '#title' => $this->t('Max Queue'),
      '#default_value' => $config->get('mt_max_queue'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Retrieve the configuration
    $this->configFactory->getEditable(static::SETTINGS)
    // Set the submitted configuration setting
    ->set('mt_content_type', $form_state->getValue('mt_content_type'))
    ->set('mt_max_queue', $form_state->getValue('mt_max_queue'))
    ->save();

    parent::submitForm($form, $form_state);
  }
}
